@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Handler::DKIM;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20191106'; # VERSION
+our $VERSION = '2.20191205'; # VERSION
 
 use Data::Dumper;
 use English qw{ -no_match_vars };
@@ -11,6 +11,7 @@ use Sys::Syslog qw{:standard :macros};
 use Mail::DKIM 0.39;
 use Mail::DKIM::Verifier 0.39;
 use Mail::DKIM::DNS;
+use Mail::DKIM::KeyValueList;
 use Mail::AuthenticationResults::Header::Entry;
 use Mail::AuthenticationResults::Header::SubEntry;
 use Mail::AuthenticationResults::Header::Comment;
@@ -61,15 +62,31 @@ sub show_domainkeys {
 }
 
 sub header_callback {
-    my ( $self, $header, $value ) = @_;
+    my ( $self, $header, $value, $original ) = @_;
     return if ( $self->{'failmode'} );
     my $EOL        = "\015\012";
-    my $dkim_chunk = $header . ': ' . $value . $EOL;
+    my $dkim_chunk = $original . $EOL;
     $dkim_chunk =~ s/\015?\012/$EOL/g;
     push @{$self->{'headers'}} , $dkim_chunk;
 
     if ( lc($header) eq 'dkim-signature' ) {
         $self->{'has_dkim'} = 1;
+
+        my $parsed = eval{ Mail::DKIM::KeyValueList->parse( $value ) };
+        $self->handle_exception( $@ );
+        if ( $parsed ) {
+            my $domain = $parsed->get_tag('d');
+            my $selector = $parsed->get_tag('s');
+            if ( $selector && $domain ) {
+                my $resolver = $self->get_object('resolver');
+                my $lookup = $selector.'._domainkey.'.$domain;
+                $resolver->bgsend( $lookup, 'TXT' );
+                $self->dbgout( 'DNSEarlyLookup', "$lookup TXT", LOG_DEBUG );
+                $lookup = '_adsp._domainkey.'.$domain;
+                $resolver->bgsend( $lookup, 'TXT' );
+                $self->dbgout( 'DNSEarlyLookup', "$lookup TXT", LOG_DEBUG );
+            }
+        }
     }
     if ( lc($header) eq 'domainkey-signature' ) {
         $self->{'has_dkim'} = 1 if $self->show_domainkeys();
@@ -429,7 +446,7 @@ Mail::Milter::Authentication::Handler::DKIM
 
 =head1 VERSION
 
-version 2.20191106
+version 2.20191205
 
 =head1 DESCRIPTION
 
