@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Handler::XGoogleDKIM;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20191106'; # VERSION
+our $VERSION = '2.20191205'; # VERSION
 
 use Data::Dumper;
 use English qw{ -no_match_vars };
@@ -45,10 +45,10 @@ sub envfrom_callback {
 }
 
 sub header_callback {
-    my ( $self, $header, $value ) = @_;
+    my ( $self, $header, $value, $original ) = @_;
     return if ( $self->{'failmode'} );
     my $EOL        = "\015\012";
-    my $dkim_chunk = $header . ': ' . $value . $EOL;
+    my $dkim_chunk = $original . $EOL;
     $dkim_chunk =~ s/\015?\012/$EOL/g;
 
     if ( lc($header) eq 'dkim-signature' ) {
@@ -66,6 +66,14 @@ sub header_callback {
         $x_dkim_chunk =~ s/\015?\012/$EOL/g;
         push @{$self->{'headers'}} , $x_dkim_chunk;
         $self->{'has_dkim'} = 1;
+        my ($domain) = $value =~ /d=([^;]*);/;
+        my ($selector) = $value =~ /s=([^;]*);/;
+        my $resolver = $self->get_object('resolver');
+        if ( $selector && $domain ) {
+            my $lookup = $selector.'._domainkey.'.$domain;
+            $resolver->bgsend( $lookup, 'TXT' );
+            $self->dbgout( 'DNSEarlyLookup', "$lookup TXT", LOG_DEBUG );
+        }
     }
 
     return;
@@ -314,7 +322,7 @@ Mail::Milter::Authentication::Handler::XGoogleDKIM
 
 =head1 VERSION
 
-version 2.20191106
+version 2.20191205
 
 =head1 DESCRIPTION
 
