@@ -1,7 +1,7 @@
 package Mail::Milter::Authentication::Protocol::SMTP;
 use strict;
 use warnings;
-our $VERSION = '2.20191106'; # VERSION
+our $VERSION = '2.20191205'; # VERSION
 
 use English qw{ -no_match_vars };
 use Email::Date::Format qw{ email_date };
@@ -572,9 +572,11 @@ sub smtp_command_data {
             if ( $value ) {
                 push @{ $smtp->{'headers'} } , $value;
                 my ( $hkey, $hvalue ) = split ( ':', $value, 2 );
-                $hvalue =~ s/^ //;
+                $hvalue =~ s/^\s+//;
+                $hkey =~ s/^\s+//;
+                $hkey =~ s/\s+$//;
                 if ( ! $fail ) {
-                    my $returncode = $handler->top_header_callback( $hkey, $hvalue );
+                    my $returncode = $handler->top_header_callback( $hkey, $hvalue, $value );
                     if ( $returncode != SMFIS_CONTINUE ) {
                         $fail = 1;
                     }
@@ -588,7 +590,7 @@ sub smtp_command_data {
         my ( $hkey, $hvalue ) = split ( ':', $value, 2 );
         $hvalue =~ s/^ //;
         if ( ! $fail ) {
-            my $returncode = $handler->top_header_callback( $hkey, $hvalue );
+            my $returncode = $handler->top_header_callback( $hkey, $hvalue, $value );
             if ( $returncode != SMFIS_CONTINUE ) {
                 $fail = 1;
             }
@@ -1080,7 +1082,7 @@ Mail::Milter::Authentication::Protocol::SMTP
 
 =head1 VERSION
 
-version 2.20191106
+version 2.20191205
 
 =head1 SYNOPSIS
 
