@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Tester::HandlerTester;
 
 use strict;
 use warnings;
-our $VERSION = '2.20191106'; # VERSION
+our $VERSION = '2.20191205'; # VERSION
 
 use Carp;
 use Clone qw{ clone };
@@ -223,8 +223,9 @@ sub rcptto {
 }
 
 sub header {
-    my ( $self, $key, $value ) = @_;
-    return $self->handler()->top_header_callback( $key, $value );
+    my ( $self, $key, $value, $original ) = @_;
+    $original = "$key: $value" if ! defined $original;
+    return $self->handler()->top_header_callback( $key, $value, $original );
 }
 
 sub end_of_headers {
@@ -366,7 +367,7 @@ Mail::Milter::Authentication::Tester::HandlerTester
 
 =head1 VERSION
 
-version 2.20191106
+version 2.20191205
 
 =head1 SYNOPSIS
 
